@@ -3,7 +3,7 @@ from tqdm import tqdm
 import scipy as sp
 from scipy import linalg
 
-
+DEFAULT_COLUMNS = ["Position_1", "Position_2", "Position_3", "Direction_1", "Direction_2", "Direction_3"]
 
 def find_locations_in_data_frames(df_1, df_2, additional_columns=[]):
     """Find matching locations of data frames ``df_1`` and ``df_2``.
@@ -15,10 +15,10 @@ def find_locations_in_data_frames(df_1, df_2, additional_columns=[]):
     :return: Vector of matching locations of both data frames.
     :rtype: array(float)
     """
-    DEFAULT_COLUMNS = ["Position_1", "Position_2", "Position_3", "Direction_1", "Direction_2", "Direction_3"]
+    
     columns = DEFAULT_COLUMNS + additional_columns
-    df_1_val = df_1[columns].values
-    df_2_val = df_2[columns].values
+    df_1_val = np.array(df_1[columns].values, dtype= np.float64)
+    df_2_val = np.array(df_2[columns].values, dtype= np.float64)
 
     # to prevent numerical errors
     df_1_val = np.round(df_1_val, 6) 
